#
# spec file for package python-sst
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-sst
Version:        0.2.4
Release:        1.167
Summary:        SST - Web Test Framework
License:        Apache-2.0
Group:          Development/Languages/Python
Url:            http://testutils.org/sst
Source:         http://pypi.python.org/packages/source/s/sst/sst-%{version}.tar.gz
BuildRequires:  python-EasyProcess
BuildRequires:  python-PyVirtualDisplay
BuildRequires:  python-argparse
BuildRequires:  python-decorator
BuildRequires:  python-devel
BuildRequires:  python-entrypoint2
BuildRequires:  python-junitxml
BuildRequires:  python-python-subunit
BuildRequires:  python-selenium
BuildRequires:  python-setuptools
BuildRequires:  python-testtools
BuildRequires:  python-unittest2
Requires:       python-EasyProcess
Requires:       python-PyVirtualDisplay
Requires:       python-argparse
Requires:       python-decorator
Requires:       python-entrypoint2
Requires:       python-junitxml
Requires:       python-python-subunit
Requires:       python-selenium
Requires:       python-testtools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
SST (selenium-simple-test) is a web test framework that uses Python
to generate functional browser-based tests.

Tests are made up of scripts, created by composing actions that drive
a browser and assert conditions. You have the flexibilty of the full
Python language, along with a convenient set of functions to simplify
web testing.

SST consists of:

 * user actions and assertions (API) in Python
 * test case loader (generates/compiles scripts to unittest cases)
 * console test runner
 * data parameterization/injection
 * selectable output reports
 * selectable browsers
 * headless (xvfb) mode
 * screenshots on errors

Test output can be displayed to the console, saved as an HTML report, or
JUnit-compatible XML for compatibility with CI systems.

%prep
%setup -q -n sst-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
# remove shebangs from all scripts
find %{buildroot}%{python_sitelib} -name '*.py' \
     -exec sed -i -e '1{/^#!/d}' {} \;

%check
python setup.py test

%files
%defattr(-,root,root,-)
%doc README examples
%{_bindir}/sst-remote
%{_bindir}/sst-run
%{_bindir}/sst-test
%{python_sitelib}/*

%changelog
* Sun Nov 17 2013 p.drouand@gmail.com
- Update to version 0.2.4
  + added ``get_text`` action
  + made it clearer that ``assert_text`` and ``assert_text_contains`` will check
    the value instead of the text for text field elements.
  + return the result of the condition checked by ``wait_for`` and
    ``wait_for_and_refresh``.
  + start documenting the debian/ubuntu packaging process.
  + requires ``set_base_url`` to be called and displaying a suitable error
    message otherwise.
  + removed HTML results reports.
  + switched to `junitxml` dependency for XML report generation.
  + skipped tests are now properly included in ``results.xml``.
  + refactored ``retry_on_stale_element`` to make a new more generic
    ``retry_on_exception``.
  + the script directory is not added to sys.path implicitly anymore.
  + ``sst-test`` can run all tests, ``nose`` is not used nor a dependency
    anymore.
  + added ``--concurrency=N`` command line argument for concurrent testing (a
    shorter ``-cN`` is also provided for convenience)
  + fix temp profile leaks when failing to connect to the firefox extension
  + fix Xvfb lock files leak
  + properly support the testtools test timing protocol (#1197298).
- Changes from 0.2.3
  + added the ``save_page_source`` action.
  + added a parameter to ``take_screenshot`` to include a timestamp in the file
    name
  + expose the SSTTestCase class which is used internally to create test cases
  + start implementing an internal test suite (#1084007)
  + ensure Xvfb is properly killed if sst-run is interrupted (#1084006)
  + protect ``wait_for`` from transient failures caused by
    StaleElementReferenceException (#1084008)
  + include test class full name in test ids for SSTScriptTestCase (#1087606)
  + add support for xfvb to SSTTestCase (#1084011)
  + removed ``junitxml`` package dependency for junit-style xml output
  + in xml report mode, progress is printed to stdout during test run
  + added ``get_window_size`` action
  + added ``set_window_size`` action
  + added ``testtools`` dependency
  + command-line test names may use glob patterns for discovery
  + added ``--collect-only`` option to ``sst-run`` command line
  + removed `Browsermob` proxy integration
  + removed ``start`` and ``stop`` actions
  + added hookable browser
- Add python-testtools and python-python-subunit Build/Requires;
  new requirement for package tests
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Jan 15 2013 p.drouand@gmail.com
- Update to 0.2.2 version:
  * No changelog available
* Mon Mar 26 2012 saschpe@suse.de
- Initial version
